import { useCallback } from "react";
import Link from "next/link";
import React from "react";
import LoginBtn from "../header/LoginBtn";
import PostButton from "./PostButton";
import MobileNavbar from "./MobileNavbar";
import { 
  FaBuilding, 
  FaLandmark, 
  FaCity, 
  FaIndustry, 
  FaUniversity, 
  FaWarehouse, 
  FaHotel, 
  FaHome 
} from "react-icons/fa";

const Header = ({ citiesData, isLoadingCities, citiesError }) => {
  const buildingIcons = [
    FaBuilding,
    FaLandmark,
    FaCity,
    FaIndustry,
    FaUniversity,
    FaWarehouse,
    FaHotel,
    FaHome
  ];

  const getIconForCity = useCallback((cityName) => {
    const hash = cityName.split('').reduce((acc, char) => {
      return char.charCodeAt(0) + ((acc << 5) - acc);
    }, 0);
    return buildingIcons[Math.abs(hash) % buildingIcons.length];
  }, []);

  const menu = [
    {
      title: "City",
      to: "#",  // Changed from empty string to "#"
      hasCities: true,
    },
    {
      title: "Buy",
      to: "/"
    },
    {
      title: "Lease",
      to: "/"
    },
    {
      title: "Project",
      to: "#",  // Changed from empty string to "#"
      subMenu: [
        { title: "By Admin", to: "/frontData/?view=adminPost" },
        { title: "Agent", to: "/frontData/?view=agentPost" },
        { title: "Developer", to: "/frontData/?view=developerPost" },
        { title: "Landowner", to: "/frontData/?view=landownerPost" }
      ]
    },
    {
      title: "Investment",
      to: "/"
    }
  ];

  return (
    <>
      <div className="hidden lg:flex justify-between px-4 sm:px-6 md:px-8 lg:px-12 xl:px-16 py-6 bg-white">
        <div className="flex flex-col sm:flex-row sm:items-center">
          <Link href={"/"} className="mb-6 sm:mb-0 sm:mr-12 lg:mr-16">
            <img src="/logo-jamin.png" alt="" className="w-[148px] h-[49px]" />
          </Link>
          <div className="flex flex-wrap gap-4 sm:gap-6 md:gap-8 lg:gap-10 xl:gap-12">
            {menu.map((item) => (
              <div key={item.title} className="relative group">
                {item.to === "#" ? (
                  <span className="block px-3 py-2 text-sm sm:text-base lg:text-lg cursor-pointer">
                    {item.title}
                  </span>
                ) : (
                  <Link href={item.to} className="block px-3 py-2 text-sm sm:text-base lg:text-lg">
                    {item.title}
                  </Link>
                )}
                {item.hasCities && !isLoadingCities && !citiesError && citiesData && (
                  <div className="absolute left-0 mt-0 w-72 sm:w-96 bg-white shadow-lg rounded-md py-2 z-10 hidden group-hover:block">
                    <div className="grid grid-cols-1 sm:grid-cols-2 gap-2 p-4">
                      {citiesData.map((city) => {
                        const IconComponent = getIconForCity(city.name);
                        return (
                          <Link
                            key={city.name}
                            href={`/city/${city.name.toLowerCase()}`}
                            className="flex items-center gap-3 px-4 py-3 hover:bg-gray-50 rounded-lg transition-colors"
                          >
                            <div className="text-gray-600">
                              <IconComponent size={24} />
                            </div>
                            <div className="flex flex-col">
                              <span className="text-sm text-gray-700">
                                {city.name}
                              </span>
                              <span className="text-xs text-gray-500">
                                ({city.count})
                              </span>
                            </div>
                          </Link>
                        );
                      })}
                    </div>
                  </div>
                )}
                {item.subMenu && (
                  <div className="absolute left-0 mt-0 w-48 bg-white shadow-lg rounded-md py-2 z-10 hidden group-hover:block">
                    {item.subMenu.map((subItem) => (
                      <Link
                        key={subItem.title}
                        href={subItem.to}
                        className="block px-4 py-2 text-sm text-gray-700 hover:bg-gray-100"
                      >
                        {subItem.title}
                      </Link>
                    ))}
                  </div>
                )}
              </div>
            ))}
          </div>
        </div>
        <div className="flex gap-4 sm:gap-6 md:gap-8 lg:gap-10 xl:gap-12 items-center">
          <LoginBtn />
          <PostButton />
          <img
            src="/header/customer-support.png"
            alt=""
            className="w-6 h-6 sm:w-8 sm:h-8 lg:w-10 lg:h-10"
          />
        </div>
      </div>
      <MobileNavbar menu={menu} />
    </>
  );
};

export default Header;